==> Software-License-0.104002.tar.gz: Software-License-0.104002/lib/Software/License/QPL_1_0.pm <==
use strict;
use warnings;
package Software::License::QPL_1_0;
$Software::License::QPL_1_0::VERSION = '0.104002';
use parent 'Software::License';
# ABSTRACT: The Q Public License, Version 1.0

sub name { 'The Q Public License, Version 1.0' }
sub url  { 'http://trolltech.com/products/qt/licenses/licensing/qpl' }

sub meta_name  { 'open_source' }
sub meta2_name { 'qpl_1_0' }
sub spdx_expression  { 'QPL-1.0' }

1;

=pod

=encoding UTF-8

=head1 NAME

Software::License::QPL_1_0 - The Q Public License, Version 1.0

=head1 VERSION

version 0.104002

=head1 PERL VERSION

This module is part of CPAN toolchain, or is treated as such.  As such, it
follows the agreement of the Perl Toolchain Gang to require no newer version of
perl than v5.8.1.  This version may change by agreement of the Toolchain Gang,
but for now is governed by the L<Lancaster
Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
of 2013.

=head1 AUTHOR

Ricardo Signes <rjbs@semiotic.systems>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022 by Ricardo Signes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__DATA__
__LICENSE__
The Q Public License
Version 1.0

Copyright (C) 1999 Trolltech AS, Norway.
Everyone is permitted to copy and distribute this license
document. 

The intent of this license is to establish freedom to share and
change the software regulated by this license under the open
source model.

This license applies to any software containing a notice
placed by the copyright holder saying that it may be
distributed under the terms of the Q Public License version
1.0. Such software is herein referred to as the Software. This
license covers modification and distribution of the Software,
use of third-party application programs based on the
Software, and development of free software which uses the
Software.

           Granted Rights

1. You are granted the non-exclusive rights set forth in this
license provided you agree to and comply with any and all
conditions in this license. Whole or partial distribution of the
Software, or software items that link with the Software, in
any form signifies acceptance of this license.

2. You may copy and distribute the Software in unmodified
form provided that the entire package, including - but not
restricted to - copyright, trademark notices and disclaimers,
as released by the initial developer of the Software, is
distributed.

3. You may make modifications to the Software and
distribute your modifications, in a form that is separate from
the Software, such as patches. The following restrictions
apply to modifications:

     a. Modifications must not alter or remove any
     copyright notices in the Software.

     b. When modifications to the Software are
     released under this license, a non-exclusive
     royalty-free right is granted to the initial
     developer of the Software to distribute your
     modification in future versions of the Software
     provided such versions remain available under
     these terms in addition to any other license(s)
     of the initial developer.

4. You may distribute machine-executable forms of the
Software or machine-executable forms of modified versions of
the Software, provided that you meet these restrictions:

     a. You must include this license document in
     the distribution.

     b. You must ensure that all recipients of the
     machine-executable forms are also able to
     receive the complete machine-readable source
     code to the distributed Software, including all
     modifications, without any charge beyond the
     costs of data transfer, and place prominent
     notices in the distribution explaining this.

     c. You must ensure that all modifications
     included in the machine-executable forms are
     available under the terms of this license.

5. You may use the original or modified versions of the
Software to compile, link and run application programs
legally developed by you or by others.

6. You may develop application programs, reusable
components and other software items that link with the
original or modified versions of the Software. These items,
when distributed, are subject to the following requirements:

     a. You must ensure that all recipients of
     machine-executable forms of these items are
     also able to receive and use the complete
     machine-readable source code to the items
     without any charge beyond the costs of data
     transfer.

     b. You must explicitly license all recipients of
     your items to use and re-distribute original and
     modified versions of the items in both
     machine-executable and source code forms.
     The recipients must be able to do so without
     any charges whatsoever, and they must be
     able to re-distribute to anyone they choose.

     c. If the items are not available to the general
     public, and the initial developer of the Software
     requests a copy of the items, then you must
     supply one.

      Limitations of Liability

In no event shall the initial developers or copyright holders be
liable for any damages whatsoever, including - but not
restricted to - lost revenue or profits or other direct, indirect,
special, incidental or consequential damages, even if they
have been advised of the possibility of such damages,
except to the extent invariable law, if any, provides
otherwise.

             No Warranty

The Software and this license document are provided AS IS
with NO WARRANTY OF ANY KIND, INCLUDING THE
WARRANTY OF DESIGN, MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE.

           Choice of Law

This license is governed by the Laws of Norway. Disputes
shall be settled by Oslo City Court.

==> Software-License-0.104003.tar.gz: Software-License-0.104003/lib/Software/License/QPL_1_0.pm <==
use strict;
use warnings;
package Software::License::QPL_1_0;
$Software::License::QPL_1_0::VERSION = '0.104003';
use parent 'Software::License';
# ABSTRACT: The Q Public License, Version 1.0

sub name { 'The Q Public License, Version 1.0' }
sub url  { 'http://trolltech.com/products/qt/licenses/licensing/qpl' }

sub meta_name  { 'open_source' }
sub meta2_name { 'qpl_1_0' }
sub spdx_expression  { 'QPL-1.0' }

1;

=pod

=encoding UTF-8

=head1 NAME

Software::License::QPL_1_0 - The Q Public License, Version 1.0

=head1 VERSION

version 0.104003

=head1 PERL VERSION

This module is part of CPAN toolchain, or is treated as such.  As such, it
follows the agreement of the Perl Toolchain Gang to require no newer version
of perl than one released in the last ten years.  This version may change by
agreement of the Toolchain Gang, but for now is governed by the L<Lancaster
Consensus|https://github.com/Perl-Toolchain-Gang/toolchain-site/blob/master/lancaster-consensus.md>
of 2013 and the Lyon Amendment of 2023 (described at the linked-to document).

Although it may work on older versions of perl, no guarantee is made that the
minimum required version will not be increased.  The version may be increased
for any reason, and there is no promise that patches will be accepted to
lower the minimum required perl.

=head1 AUTHOR

Ricardo Signes <rjbs@semiotic.systems>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023 by Ricardo Signes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__DATA__
__LICENSE__
The Q Public License
Version 1.0

Copyright (C) 1999 Trolltech AS, Norway.
Everyone is permitted to copy and distribute this license
document. 

The intent of this license is to establish freedom to share and
change the software regulated by this license under the open
source model.

This license applies to any software containing a notice
placed by the copyright holder saying that it may be
distributed under the terms of the Q Public License version
1.0. Such software is herein referred to as the Software. This
license covers modification and distribution of the Software,
use of third-party application programs based on the
Software, and development of free software which uses the
Software.

           Granted Rights

1. You are granted the non-exclusive rights set forth in this
license provided you agree to and comply with any and all
conditions in this license. Whole or partial distribution of the
Software, or software items that link with the Software, in
any form signifies acceptance of this license.

2. You may copy and distribute the Software in unmodified
form provided that the entire package, including - but not
restricted to - copyright, trademark notices and disclaimers,
as released by the initial developer of the Software, is
distributed.

3. You may make modifications to the Software and
distribute your modifications, in a form that is separate from
the Software, such as patches. The following restrictions
apply to modifications:

     a. Modifications must not alter or remove any
     copyright notices in the Software.

     b. When modifications to the Software are
     released under this license, a non-exclusive
     royalty-free right is granted to the initial
     developer of the Software to distribute your
     modification in future versions of the Software
     provided such versions remain available under
     these terms in addition to any other license(s)
     of the initial developer.

4. You may distribute machine-executable forms of the
Software or machine-executable forms of modified versions of
the Software, provided that you meet these restrictions:

     a. You must include this license document in
     the distribution.

     b. You must ensure that all recipients of the
     machine-executable forms are also able to
     receive the complete machine-readable source
     code to the distributed Software, including all
     modifications, without any charge beyond the
     costs of data transfer, and place prominent
     notices in the distribution explaining this.

     c. You must ensure that all modifications
     included in the machine-executable forms are
     available under the terms of this license.

5. You may use the original or modified versions of the
Software to compile, link and run application programs
legally developed by you or by others.

6. You may develop application programs, reusable
components and other software items that link with the
original or modified versions of the Software. These items,
when distributed, are subject to the following requirements:

     a. You must ensure that all recipients of
     machine-executable forms of these items are
     also able to receive and use the complete
     machine-readable source code to the items
     without any charge beyond the costs of data
     transfer.

     b. You must explicitly license all recipients of
     your items to use and re-distribute original and
     modified versions of the items in both
     machine-executable and source code forms.
     The recipients must be able to do so without
     any charges whatsoever, and they must be
     able to re-distribute to anyone they choose.

     c. If the items are not available to the general
     public, and the initial developer of the Software
     requests a copy of the items, then you must
     supply one.

      Limitations of Liability

In no event shall the initial developers or copyright holders be
liable for any damages whatsoever, including - but not
restricted to - lost revenue or profits or other direct, indirect,
special, incidental or consequential damages, even if they
have been advised of the possibility of such damages,
except to the extent invariable law, if any, provides
otherwise.

             No Warranty

The Software and this license document are provided AS IS
with NO WARRANTY OF ANY KIND, INCLUDING THE
WARRANTY OF DESIGN, MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE.

           Choice of Law

This license is governed by the Laws of Norway. Disputes
shall be settled by Oslo City Court.
